/**
 * Copyright (c) 2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.seflowable;

import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.ow2.petals.admin.jmx.JMXPetalsAdministration;
import org.ow2.petals.cli.shell.command.AbstractPetalsCliCommand;
import org.ow2.petals.jmx.api.api.JMXClient;

/**
 * Abstract class for command about Petals SE Flowable
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public abstract class AbstractCommand extends AbstractPetalsCliCommand {

    /**
     * The option associated to the component id
     */
    public static final String COMPONENT_ID_LONG_OPTION = "component-id";

    public static final String COMPONENT_ID_SHORT_OPTION = "n";

    public static final String DEFAULT_COMPONENT_ID = "petals-se-flowable";

    protected static final Option COMPONENT_NAME_OPTION = Option.builder(COMPONENT_ID_SHORT_OPTION).required(false)
            .numberOfArgs(1).argName("component-id")
            .desc("The identifier of the component. Default: petals-se-flowable").longOpt(COMPONENT_ID_LONG_OPTION)
            .build();

    private JMXClient jmxClient;

    public AbstractCommand(final String name) {
        super("se-flowable." + name);
    }

    @Override
    public Options createOptions() {
        return super.createOptions().addOption(COMPONENT_NAME_OPTION);
    }

    /**
     * Use ONLY if JMXClient itself is needed, and do not forget to inject it in {@link #jmxClient} in tests!
     * 
     * @return a lower-level JMXClient
     */
    protected JMXClient getJMXClient() {
        // client must absolutely be injected for the tests!
        if (jmxClient == null) {
            // we must cast because PetalsAdministration does not support the functionalities provided by it
            jmxClient = ((JMXPetalsAdministration) getAdmin()).getJMXClient();
        }
        return jmxClient;
    }

    /**
     * This must be public to be accessible from tests
     */
    public void setJMXClient(JMXClient jmxClient) {
        this.jmxClient = jmxClient;
    }
}
