/**
 * Copyright (c) 2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.seflowable;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.junit.Before;
import org.junit.Rule;
import org.ow2.petals.cli.extension.seflowable.mock.ProcDefStruct;
import org.ow2.petals.cli.shell.command.AbstractConnectedShellTest;
import org.ow2.petals.jmx.api.mock.junit.PetalsJmxApiJunitRule;

/**
 * Unit test of {@link ListProcessInstances}.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class AbstractTest extends AbstractConnectedShellTest {

    protected static final Map<ProcDefStruct, List<String>> PROCESS_INSTANCES = new ConcurrentHashMap<>();

    protected static final Map<String, List<String>> FLOW_INSTANCES = new ConcurrentHashMap<>();

    public static final String PROCESS_DEFINITION_KEY_1 = "process-definition-1";

    public static final String PROCESS_DEFINITION_KEY_2 = "process-definition-2";

    public static final String PROCESS_INSTANCE_11_1 = "process-instance-11-1";

    public static final String PROCESS_INSTANCE_11_2 = "process-instance-11-2";

    public static final String PROCESS_INSTANCE_12_1 = "process-instance-12-1";

    public static final String PROCESS_INSTANCE_21_1 = "process-instance-21-1";

    public static final String PROCESS_INSTANCE_21_2 = "process-instance-21-2";

    public static final String FLOW_INSTANCE_11_1_1 = "flow-instance-11-1-1";

    public static final String FLOW_INSTANCE_11_1_2 = "flow-instance-11-1-2";

    public static final String FLOW_INSTANCE_11_2_1 = "flow-instance-11-2-1";

    public static final String FLOW_INSTANCE_12_1_1 = "flow-instance-12-1-1";

    public static final String FLOW_INSTANCE_12_1_2 = "flow-instance-12-1-2";

    public static final String FLOW_INSTANCE_21_1_1 = "flow-instance-21-1-1";

    public static final String FLOW_INSTANCE_21_1_2 = "flow-instance-21-1-2";

    public static final String FLOW_INSTANCE_21_2_1 = "flow-instance-21-2-1";

    @Before
    public void initProcessInstances() {
        final ProcDefStruct procDef11 = new ProcDefStruct(PROCESS_DEFINITION_KEY_1, "1");
        final ProcDefStruct procDef12 = new ProcDefStruct(PROCESS_DEFINITION_KEY_1, "2");
        final ProcDefStruct procDef21 = new ProcDefStruct(PROCESS_DEFINITION_KEY_2, "1");

        PROCESS_INSTANCES.put(procDef11, new ArrayList<String>());
        PROCESS_INSTANCES.get(procDef11).add(PROCESS_INSTANCE_11_1);
        PROCESS_INSTANCES.get(procDef11).add(PROCESS_INSTANCE_11_2);
        PROCESS_INSTANCES.put(procDef12, new ArrayList<String>());
        PROCESS_INSTANCES.get(procDef12).add(PROCESS_INSTANCE_12_1);
        PROCESS_INSTANCES.put(procDef21, new ArrayList<String>());
        PROCESS_INSTANCES.get(procDef21).add(PROCESS_INSTANCE_21_1);
        PROCESS_INSTANCES.get(procDef21).add(PROCESS_INSTANCE_21_2);

        FLOW_INSTANCES.put(PROCESS_INSTANCE_11_1, new ArrayList<String>());
        FLOW_INSTANCES.get(PROCESS_INSTANCE_11_1).add(FLOW_INSTANCE_11_1_1);
        FLOW_INSTANCES.get(PROCESS_INSTANCE_11_1).add(FLOW_INSTANCE_11_1_2);

        FLOW_INSTANCES.put(PROCESS_INSTANCE_11_2, new ArrayList<String>());
        FLOW_INSTANCES.get(PROCESS_INSTANCE_11_2).add(FLOW_INSTANCE_11_2_1);

        FLOW_INSTANCES.put(PROCESS_INSTANCE_12_1, new ArrayList<String>());
        FLOW_INSTANCES.get(PROCESS_INSTANCE_12_1).add(FLOW_INSTANCE_12_1_1);
        FLOW_INSTANCES.get(PROCESS_INSTANCE_12_1).add(FLOW_INSTANCE_12_1_2);

        FLOW_INSTANCES.put(PROCESS_INSTANCE_21_1, new ArrayList<String>());
        FLOW_INSTANCES.get(PROCESS_INSTANCE_21_1).add(FLOW_INSTANCE_21_1_1);
        FLOW_INSTANCES.get(PROCESS_INSTANCE_21_1).add(FLOW_INSTANCE_21_1_2);

        FLOW_INSTANCES.put(PROCESS_INSTANCE_21_2, new ArrayList<String>());
        FLOW_INSTANCES.get(PROCESS_INSTANCE_21_2).add(FLOW_INSTANCE_21_2_1);
    }

    @Rule
    public final PetalsJmxApiJunitRule jmxApi = new PetalsJmxApiJunitRule();
}
